@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 530 $ : Last Committed Revision
- * $Date: 2010-06-16 16:52:19 -0700 (Wed, 16 Jun 2010) $ : Last Committed Date */
+ * $Revision: 544 $ : Last Committed Revision
+ * $Date: 2010-06-23 15:45:12 -0700 (Wed, 23 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -670,6 +670,12 @@ listen_Thread( LPVOID arg )
 
 #endif
 
+#ifdef NEW_SECURITY
+  int ret;
+  int nonce;
+  unsigned char aes_key[36];
+#endif
+
   char peer_name[45];	
   connection_p connection;
   u_long connection_number;
