@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 404 $ : Last Committed Revision
- * $Date: 2009-09-04 17:32:54 -0700 (Fri, 04 Sep 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
@@ -50,7 +50,7 @@ interpreter_variable_data_New(void)
   CHECK_NULL(agent_variable_data, exit(0););
   agent_variable_data->name = NULL;
   agent_variable_data->size = 0;
-  agent_variable_data->data_type = 0;
+  agent_variable_data->data_type = (ChType_t)0;
   agent_variable_data->array_dim = 0;
   agent_variable_data->array_extent = NULL;
   agent_variable_data->data = NULL;
