@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 529 $ : Last Committed Revision
- * $Date: 2010-06-16 16:00:50 -0700 (Wed, 16 Jun 2010) $ : Last Committed Date */
+ * $Revision: 545 $ : Last Committed Revision
+ * $Date: 2010-08-04 13:20:13 -0700 (Wed, 04 Aug 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -373,16 +373,12 @@ int handler_HELP(void *arg, mc_platform_p global) /*{{{*/
 int handler_SEND(void *arg, mc_platform_p global) /*{{{*/
 {
     command_t* cmd = (command_t*)arg;
-    if(cmd->num_args != 4) 
+    if(cmd->num_args != 2) 
     {
         printf("%s\n", command_descriptions[COMMAND_SEND]);
         return 0;
     }
-    return MC_SendAgentMigrationMessageFile(
-            NULL,
-            cmd->args[1],
-            cmd->args[2],
-            atoi(cmd->args[3])); 
+    return MC_SendAgentFile(NULL, cmd->args[1]);
 } /*}}}*/
     
 int handler_PRINT_CONNECTLIST(void *arg, mc_platform_p global) /*{{{*/
