@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 392 $ : Last Committed Revision
- * $Date: 2009-08-02 17:47:35 -0700 (Sun, 02 Aug 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -674,7 +674,7 @@ int fipa_word_Parse(fipa_word_t** word, fipa_message_string_p message)
   }
   *word = (fipa_word_t*)malloc(sizeof(fipa_word_t));
   CHECK_NULL(*word, exit(0););
-  (*word)->content = malloc
+  (*word)->content = (char*)malloc
     (
      sizeof(char) * (i+1)
     );
