@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 527 $ : Last Committed Revision
- * $Date: 2010-06-16 13:25:08 -0700 (Wed, 16 Jun 2010) $ : Last Committed Date */
+ * $Revision: 545 $ : Last Committed Revision
+ * $Date: 2010-08-04 13:20:13 -0700 (Wed, 04 Aug 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -466,9 +466,9 @@ auth_rece_send_msg(int sockfd, char *hostname, char *message, char *privkey, cha
   strcpy(infile, "msgXXXXXX");
   fd1 = mkstemp(infile);
   if (fd1 == -1) {
-     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
-          infile, __FILE__, __LINE__ );
-     exit(EXIT_FAILURE);
+    fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+        infile, __FILE__, __LINE__ );
+    exit(EXIT_FAILURE);
   } 
   close(fd1);
 
@@ -476,21 +476,21 @@ auth_rece_send_msg(int sockfd, char *hostname, char *message, char *privkey, cha
   strcpy(outfile, "en-msgXXXXXX");
   fd1 = mkstemp(outfile);
   if (fd1 == -1) {
-     fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
-           outfile, __FILE__, __LINE__ );
-     exit(EXIT_FAILURE);
-  }
-  close(fd1);
-/*  
-  tempfile = (char *)malloc(sizeof(char)*20);
-  strcpy(tempfile, "tempXXXXXX");
-  fd1 = mkstemp(tempfile);
-  if(fd == -1){
-    printf("Could not create temporary file \n");
+    fprintf(stderr, "Could not create temporary file:%s. %s:%d\n",
+        outfile, __FILE__, __LINE__ );
     exit(EXIT_FAILURE);
   }
   close(fd1);
-*/
+  /*  
+      tempfile = (char *)malloc(sizeof(char)*20);
+      strcpy(tempfile, "tempXXXXXX");
+      fd1 = mkstemp(tempfile);
+      if(fd == -1){
+      printf("Could not create temporary file \n");
+      exit(EXIT_FAILURE);
+      }
+      close(fd1);
+      */
 #else
   infile  = _tempnam(".", "msg");
   outfile = _tempnam(".", "en-msg");
@@ -500,63 +500,63 @@ auth_rece_send_msg(int sockfd, char *hostname, char *message, char *privkey, cha
      num = rand();
      sprintf(infile , "msg%d", num);
      sprintf(outfile, "en-msg%d", num);
-  */     
+     */     
   strcpy(privatekey, privkey);
   //printf("\n ################################### \n");	
   //printf("Authenticating %s \n", hostname);	
   //printf("Known host file lookup for peer public key ... \n");
   // Known host file lookup for peer public key 
   if (read_known_host_file(peer_pubkey, hostname, known_host_filename) == -1 ){
-     printf("Client: %s 's Public key not found in know host file\n", hostname);
-     if( remove(infile) ) printf("message.c : remove error 4");
-     if( remove(outfile) ) printf("message.c : remove error 5");
+    printf("Client: %s 's Public key not found in know host file\n", hostname);
+    if( remove(infile) ) printf("message.c : remove error 4");
+    if( remove(outfile) ) printf("message.c : remove error 5");
 #ifndef _WIN32
-       //close(sockfd);
+    //close(sockfd);
 #else
-       //closesocket(sockfd);
+    //closesocket(sockfd);
 #endif
   }else{
-       if ((ret=initiate_migration_process(sockfd, &nonce, peer_pubkey, privatekey, aes_key)) != 1){
-          if (ret == -1)
-             printf("Client: Connected peer is not authenticated \n");
-          if (ret == -2)
-             printf("Client: Unable to get authentication from oither peer \n");
-       }else{
-		//printf("Successfully Authenticate %s \n", hostname); 
-    		// printf("AES key is exchanged. \n");
+    if ((ret=initiate_migration_process(sockfd, &nonce, peer_pubkey, privatekey, aes_key)) != 1){
+      if (ret == -1)
+        printf("Client: Connected peer is not authenticated \n");
+      if (ret == -2)
+        printf("Client: Unable to get authentication from oither peer \n");
+    }else{
+      //printf("Successfully Authenticate %s \n", hostname); 
+      // printf("AES key is exchanged. \n");
 
-			// writing message (that is to be send) in a file.
-   		if( (fd = fopen(infile,"w")) == NULL){
-      		   printf("Unable to write message in a file \n");
-	           if( remove(infile) ) printf("message.c : remove error 1");
-      		}else{
-		     //printf("message length = %d \n", strlen(message) );	 
-      		     fwrite (message , 1 , strlen(message) , fd );
-                     fclose(fd);  
-                     // Encrypt message file
-                     mode = 0; // Encryption
-                     if (aes_en_de(mode, infile, outfile, aes_key, &nonce, 0) != 1){
-                         printf("Client: AES Encryption Failed \n");
-			 if( remove(infile) ) printf("message.c : remove error 2"); 
-	                 if( remove(outfile) ) printf("message.c : remove error 3");
-                 }else{	
-		      if( remove(infile) ) printf("message.c : remove error 4");
-                      if (send_AES_en_MA(sockfd, &nonce, outfile, peer_pubkey) != 1  ){
-                          printf("Client: Error while sending mobile agent \n");
-			  if( remove(outfile) ) printf("message.c : remove error 5");
-		      }else{
-			   if( remove(outfile) ) printf("message.c : remove error 6");
-                           //printf(" Successfully send the message \n");
-					       ret = 2;	
-					   }
-                  }
-             }
+      // writing message (that is to be send) in a file.
+      if( (fd = fopen(infile,"w")) == NULL){
+        printf("Unable to write message in a file \n");
+        if( remove(infile) ) printf("message.c : remove error 1");
+      }else{
+        //printf("message length = %d \n", strlen(message) );	 
+        fwrite (message , 1 , strlen(message) , fd );
+        fclose(fd);  
+        // Encrypt message file
+        mode = 0; // Encryption
+        if (aes_en_de(mode, infile, outfile, aes_key, &nonce, 0) != 1){
+          printf("Client: AES Encryption Failed \n");
+          if( remove(infile) ) printf("message.c : remove error 2"); 
+          if( remove(outfile) ) printf("message.c : remove error 3");
+        }else{	
+          if( remove(infile) ) printf("message.c : remove error 4");
+          if (send_AES_en_MA(sockfd, &nonce, outfile, peer_pubkey) != 1  ){
+            printf("Client: Error while sending mobile agent \n");
+            if( remove(outfile) ) printf("message.c : remove error 5");
+          }else{
+            if( remove(outfile) ) printf("message.c : remove error 6");
+            //printf(" Successfully send the message \n");
+            ret = 2;	
+          }
         }
-   }
+      }
+    }
+  }
   // printf("------------------------------ \n");  
-//  free(infile);
-//  free(outfile);
-//  free(tempfile);
+  //  free(infile);
+  //  free(outfile);
+  //  free(tempfile);
   return ret;
 }
 
@@ -636,6 +636,9 @@ message_send_Thread( LPVOID arg )
 	int errnum;
 
 	dynstring_t* message_string;
+#ifdef NEW_SECURITY
+  int ret;
+#endif
 
 	mc_platform = ((message_send_arg_t*)arg)->mc_platform;
 	message = ((message_send_arg_t*)arg)->message;
